# main.py
from fastapi import FastAPI, HTTPException, Depends
from fastapi.middleware.cors import CORSMiddleware
from fastapi.security import OAuth2PasswordRequestForm
from my_auth_lib.auth import register_user, login_user
from my_auth_lib.dependencies import get_current_user
from schemas import UserCreate

app = FastAPI()

app.add_middleware(
    CORSMiddleware,
    allow_origins=["http://localhost:5173"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

@app.post("/register")
def register(user: UserCreate):
    return register_user(user)

@app.post("/login")
def login(form_data: OAuth2PasswordRequestForm = Depends()):
    return login_user(form_data)

@app.get("/profile")
def get_profile(current_user: dict = Depends(get_current_user)):
    return {"message": "Welcome!", "user": current_user}
